/*
 * Modificare questo file e copiarlo come userChrome.css nel proprio
 * profilo-directory/chrome/
 */

/*
 * Questo file può essere utilizzato per personalizzare l'aspetto ddell'interfaccia di Mozilla
 * Si suggerisce di utilizzare !important sulle regole in cui si desidera
 * sovrascrivere le impostazioni predefinite.
 */

/*
 * Non rimuovere la riga @namespace -- E' necessaria per il corretto funzionamento
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* imposta il  namespace predefinito per XUL */


/*
 * Alcuni miglioramenti possibili di accessibilità:
 */
/*
 * Imposta le dimensioni predefinite dei font a 20 pt:
 *
 * * {
 *   font-size: 20pt !important
 * }
 */
/*
 * Imposta alcune voci di menu in particolare a 15 pt invece della dimensione predefinita:
 *
 * menupopup > * {
 *   font-size: 15pt !important
 * }
 */
/*
 * Imposta un font a spaziatura fissa per la barra degli indirizzi (URL)
 *
 * #urlbar {
 *    font-family: monospace !important;
 * }
 */

/*
 * Elimina il throbber e il suo noioso movimento:
 *
 * #throbber-box {
 *   display: none !important;
 * }
 */

/*
 * Per altri esempi consultare http://www.mozilla.org/unix/customizing.html
 */
 
